@@ -3,8 +3,8 @@
  * 
  * Home page: http://plasma-gate.weizmann.ac.il/Grace/
  * 
- * Copyright (c) 1996-99 Grace Development Team
- * Copyright (c) 1991-95 Paul J Turner, Portland, OR
+ * Copyright (c) 1991-1995 Paul J Turner, Portland, OR
+ * Copyright (c) 1996-2000 Grace Development Team
  * 
  * Maintained by Evgeny Stambulchik <fnevgeny@plasma-gate.weizmann.ac.il>
  * 
@@ -28,16 +28,18 @@
 
 #include "defines.h"
 
+#define GMF_VERSION "0.9"
+
 int mfinitgraphics(void);
 
 void mf_drawpixel(VPoint vp);
 void mf_drawpolyline(VPoint *vps, int n, int mode);
 void mf_fillpolygon(VPoint *vps, int nc);
 void mf_drawarc(VPoint vp1, VPoint vp2, int a1, int a2);
-void mf_fillarc(VPoint vp1, VPoint vp2, int a1, int a2);
+void mf_fillarc(VPoint vp1, VPoint vp2, int a1, int a2, int mode);
 void mf_putpixmap(VPoint vp, int width, int height, 
      char *databits, int pixmap_bpp, int bitmap_pad, int pixmap_type);
-void mf_puttext (VPoint start, VPoint end, double size, 
-                                            CompositeString *cstring);
+void mf_puttext (VPoint vp, char *s, int len, int font,
+     TextMatrix *tm, int underline, int overline, int kerning);
 
 void mf_leavegraphics(void);
